"use strict";
/**
 * HTTP settings.
 * @class
 */
class HttpProfile {
    /**
     * @param {string} protocol Only supports https://.
     * @param {string} endpoint Domain name, such as cvm.ap-shanghai.tcecloud.com.
     * @param {string} reqMethod HTTP method, only supports GET and POST.
     * @param {number} reqTimeout Request timeout value, in seconds, default 60.
     */
    constructor(protocol, endpoint, reqMethod, reqTimeout, headers = {}) {
        /**
         * @type {string}
         */
        this.reqMethod = reqMethod || 'POST';
        /**
         * 接入点域名，形如（product.api3.{{conf.main_domain}}），product即接入TCE的产品名，如CVM VPC CLB等，api3是调用版本，{{conf.main_domain}}是主域名。
         * @type {string || null}
         */
        this.endpoint = endpoint || null;
        /**
         * @type {string}
         */
        this.protocol = protocol || 'https://';
        /**
         * @type {number}
         */
        this.reqTimeout = reqTimeout || 60;
        this.headers = headers;
    }
}
module.exports = HttpProfile;
